clear;close all;clc;FS=14;

pkg load io
pkg load windows 

data=xlsread('MtbH37Rv','Raw date','B4:U67');
%save('-v7','dataset.mat','data');
%load dataset

t=0:7;
[Ro,Col]=size(data);

% Calculations of means and standard deviations for all samples
PD=[];
for k=1:Col;
  d=reshape(data(:,k),[8 8]);
  dm{k}=mean(d);
  de{k}=std(d/dm{k}(1))/sqrt(5);
  dm{k}=dm{k}/dm{k}(1);
  pd=polyfit(t(1:5),log(dm{k}(1:5)),2);
  PD=[PD pd'];
  c=corrcoef(log(dm{k}(1:5)),polyval(pd,t(1:5)));
  cc(k)=c(1,2);
end

figure

  subplot(2,1,1)
  plot([1:4:Col],PD(2,1:4:Col),'o')
  hold on
  plot([2:4:Col],PD(2,2:4:Col),'s')
  plot([3:4:Col],PD(2,3:4:Col),'*')
  plot([4:4:Col],PD(2,4:4:Col),'d') 
xlim([0 Col+1])  
xlabel('Trial`s #')
ylabel('r, day^{-1}')
text(1,0.4,'(A)','FontSize',FS)
set(gca,'FontSize',FS)
  subplot(2,1,2)
    
  plot([1:4:Col],sqrt(2*PD(1,1:4:Col)),'o')
  hold on
  plot([2:4:Col],sqrt(2*PD(1,2:4:Col)),'s')
  plot([3:4:Col],sqrt(2*PD(1,3:4:Col)),'*')
  plot([4:4:Col],sqrt(2*PD(1,4:4:Col)),'d')
xlim([0 Col+1])
xlabel('Trial`s #')
ylabel('\sigma, day^{-1}')
text(1,0.5,'(B)','FontSize',FS)
set(gca,'FontSize',FS)

print -dpdf figmusigma '-S620,540'

%% Averages and standard errors
mean(PD(2,1:4:Col))
std(PD(2,1:4:Col))/5
mean(sqrt(2*PD(1,1:4:Col)))
std(sqrt(2*PD(1,1:4:Col)))/5

mean(PD(2,2:4:Col))
std(PD(2,2:4:Col))/5
mean(sqrt(2*PD(1,2:4:Col)))
std(sqrt(2*PD(1,2:4:Col)))/5

mean(PD(2,3:4:Col))
std(PD(2,3:4:Col))/5
mean(sqrt(2*PD(1,3:4:Col)))
std(sqrt(2*PD(1,3:4:Col)))/5

mean(PD(2,4:4:Col))
std(PD(2,4:4:Col))/5
mean(sqrt(2*PD(1,4:4:Col)))
std(sqrt(2*PD(1,4:4:Col)))/5

%% Illustrative figures

figure
subplot(5,1,[1 3])

tf=linspace(0,4.2,51);

hold on
e1=errorbar(t,log(dm{17}),log(1+de{17}/dm{17}));
set(e1,'color','blue','LineStyle',':')
plot(tf,polyval(PD(:,17),tf),'color','blue','LineWidth',1.5)
%plot(t,log(dm{14}),'s','color','black')
e1=errorbar(t,log(dm{14}),log(1+de{14}/dm{14}));
set(e1,'color','black','LineStyle',':')
plot(tf,polyval(PD(:,14),tf),'color','black','LineWidth',1.5)
%plot(t,log(dm{7}),'*','color','green')
e1=errorbar(t,log(dm{7}),log(1+de{7}/dm{7}));
set(e1,'color','green','LineStyle',':')
plot(tf,polyval(PD(:,7),tf),'color','green','LineWidth',1.5)
%plot(t,log(dm{8}),'d','color','red')
e1=errorbar(t,log(dm{8}),log(1+de{8}/dm{8}));
set(e1,'color','red','LineStyle',':')
plot(tf,polyval(PD(:,8),tf),'color','red','LineWidth',1.5)
xlim([-0.25 7.5])
ylim([-0.25 4.5])
xlabel('t, days')
ylabel('log(N/N_0)')
text(0,4,'(A)','FontSize',FS)
set(gca,'FontSize',FS)
box

subplot(5,1,[4 5])
tm=linspace(1,8,51);
V=3234./(1+exp(-0.957*(tm-6.18)));
G=5350*exp(-exp(-0.295*(tm-6.8)));
M=exp(0.93*tm+2.2);

plot(tm-1,log(V/V(1)),'color','cyan','LineWidth',2)
hold on
plot(tm-1,log(M/M(1)),'--','color',[0.5 0.5 0.5],'LineWidth',1)
plot(tm-1,log(G/G(1)),'-.','color','magenta','LineWidth',1)
xlim([-0.25 7.5])
ylim([-0.5 6.5])
xlabel('t, days')
ylabel('log(N/N_0)')
text(0,5,'(B)','FontSize',FS)
l=legend('Verhulst','Malthus','Gompertz');
set(l,'FontSize',FS,'Location','southeast')
set(gca,'FontSize',FS)

print -dpdf figexample '-S620,540'

